@@ -32,9 +32,11 @@
 #  define dXSBOOTARGSXSAPIVERCHK dXSARGS
 #endif
 
+/* Perl_xs_boot_epilog - introduced in 5.21.6 (use 5.22 as safe boundary)
+ * Use PERL_IMPLICIT_CONTEXT not USE_ITHREADS - that's what controls aTHX_ expansion */
 #if !PERL_VERSION_GE(5,22,0)
 #  ifndef Perl_xs_boot_epilog
-#    ifdef USE_ITHREADS
+#    ifdef PERL_IMPLICIT_CONTEXT
 #      define Perl_xs_boot_epilog(ctx, ax) XSRETURN_YES
 #    else
 #      define Perl_xs_boot_epilog(ax) XSRETURN_YES
